Cross Sectional
---------------

.. currentmodule:: prismstudio


.. autosummary::
    :toctree: api/

    _PrismComponent.cross_sectional_rank
    _PrismComponent.cross_sectional_percentile
    _PrismComponent.cross_sectional_quantile
    _PrismComponent.cross_sectional_z_score
    _PrismComponent.cross_sectional_demean
    _PrismComponent.cross_sectional_mean
    _PrismComponent.cross_sectional_std
    _PrismComponent.cross_sectional_skew
    _PrismComponent.cross_sectional_kurt
    _PrismComponent.cross_sectional_median
    _PrismComponent.cross_sectional_mode
    _PrismComponent.cross_sectional_sum
    _PrismComponent.cross_sectional_prod
    _PrismComponent.cross_sectional_count
    _PrismComponent.cross_sectional_max
    _PrismComponent.cross_sectional_min
